Package: rrcovHD
Title: Robust Multivariate Methods for High Dimensional Data
Version: 0.3-1
VersionNote: Released 0.3-0 on 2024-02-04 on CRAN
Authors@R: c(person("Valentin", "Todorov", role = c("aut", "cre"), email = "valentin.todorov@chello.at", comment=c(ORCID = "0000-0003-4215-0245")))
Description: Robust multivariate methods for high dimensional data including
        outlier detection (Filzmoser and Todorov (2013) <doi:10.1016/j.ins.2012.10.017>), 
        robust sparse PCA (Croux et al. (2013) <doi:10.1080/00401706.2012.727746>, Todorov and Filzmoser (2013) <doi:10.1007/978-3-642-33042-1_31>), 
        robust PLS (Todorov and Filzmoser (2014) <doi:10.17713/ajs.v43i4.44>), 
        and robust sparse classification (Ortner et al. (2020) <doi:10.1007/s10618-019-00666-8>).
Maintainer: Valentin Todorov <valentin.todorov@chello.at>
Depends: rrcov (>= 1.3-7), robustbase (>= 0.92-1), methods
Imports: stats4, pls, spls, pcaPP, robustHD, Rcpp
LinkingTo: Rcpp
Suggests: MASS
LazyLoad: yes
LazyData: yes
License: GPL (>= 3)
URL: https://github.com/valentint/rrcovHD
BugReports: https://github.com/valentint/rrcovHD/issues
Packaged: 2024-08-17 21:20:57 UTC; valen
NeedsCompilation: yes
Repository: CRAN
Author: Valentin Todorov [aut, cre] (<https://orcid.org/0000-0003-4215-0245>)
Date/Publication: 2024-08-17 21:40:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-28 20:57:50 UTC; unix
Archs: rrcovHD.so.dSYM
